@@ -6,6 +6,10 @@ CONFIG = {
         "help": "The plugin used to serialize data. Defaults to json",
         "default": "json",
     },
+    "error_callback_ref": {
+        "help": "A reference to a function on the hub that will handle messages that failed to publish",
+        "default": None,
+    },
 }
 DYNE = {
     "log": ["log"],
