@@ -19,6 +19,9 @@ async def profiles(
         hub.log.debug("Reading profiles from acct")
         acct_data = await hub.acct.init.profiles(acct_file, acct_key, **kwargs)
 
+    if acct_data is None:
+        acct_data = {}
+
     ret_data = data.NamespaceDict()
 
     for provider, profiles in acct_data.items():
