@@ -1,7 +1,7 @@
 import asyncio
 import dataclasses
 import queue
-from random import randint
+import uuid
 from typing import Any
 from typing import Dict
 from typing import List
@@ -36,8 +36,12 @@ async def init(hub):
         new_bus = asyncio.PriorityQueue()
         while not hub.evbus.BUS.empty():
             queue_item = hub.evbus.BUS.get()
-            # The item should already be a tuple here
-            new_bus.put_nowait(queue_item)
+            if isinstance(queue_item, tuple):
+                new_bus.put_nowait(queue_item)
+            else:
+                # If the item exists in original synchronous queue without priority
+                # Add the priority before putting into priority queue in this conversion
+                new_bus.put_nowait((_random_priority(), queue_item))
 
         hub.evbus.BUS = new_bus
     return hub.evbus.BUS
@@ -59,8 +63,16 @@ def put_nowait(hub, body: str, profile: str = "default"):
     """
     Put an event on the bus as a single data class
     """
-    bus: asyncio.PriorityQueue = hub.evbus.BUS
-    bus.put_nowait(_create_queue_item(hub, body, profile))
+
+    if not isinstance(hub.evbus.BUS, asyncio.PriorityQueue):
+        # The event bus init may not complete before items starts going into the queue
+        # All events before init will be inserted into regular queue.
+        # init converts synchronous queue into asynchronous queue (priority queue)
+        serialized: bytes = hub.serial[hub.evbus.SERIAL_PLUGIN].dump(body)
+        hub.evbus.BUS.put_nowait(Event(body=serialized, profile=profile))
+    else:
+        bus: asyncio.PriorityQueue = hub.evbus.BUS
+        bus.put_nowait(_create_queue_item(hub, body, profile))
 
 
 async def propagate(
@@ -129,5 +141,18 @@ async def wrap(hub, plugin_name, event, contexts, coro):
 
 def _create_queue_item(hub, body: str, profile: str = "default") -> tuple:
     serialized: bytes = hub.serial[hub.evbus.SERIAL_PLUGIN].dump(body)
-    # Duplicate priority is okay as the order is not important when publishing event
-    return randint(0, 100), Event(body=serialized, profile=profile)
+    return _random_priority(), Event(body=serialized, profile=profile)
+
+
+def _random_priority() -> int:
+    # Using uuid4 so that priority value collision chances are very less.
+    # If used a random number and there is a collision,
+    #   - It would fall back on comparing Event object
+    #   - Event has no comparator and would fail with TypeError
+    #       - Error: '<' not supported between instances of 'Event' and 'Event'
+    #       - There is no comparator for Event dataclass
+    #
+    # Store everything as negative, as it is using min-heap
+    # CAUTION: DO NOT use this method for storing terminal (STOP_ITERATION) event.
+    # The terminal event should be the highest number in the heap, so it is fetched last
+    return -1 * int(uuid.uuid4())
