@@ -1,4 +1,5 @@
 import asyncio
+import sys
 from typing import Any
 from typing import Dict
 from typing import List
@@ -20,7 +21,8 @@ async def start(hub, contexts: Dict[str, List[Dict[str, Any]]]):
     bus: asyncio.Queue = await hub.evbus.broker.init()
 
     while True:
-        event = await bus.get()
+        item = await bus.get()
+        event = item[1]
         if event is STOP_ITERATION:
             hub.log.info("Event bus was forced to stop")
             return
@@ -32,7 +34,9 @@ async def stop(hub):
     Stop the event bus
     """
     hub.log.debug("Stopping the event bus")
-    hub.evbus.BUS.put_nowait(STOP_ITERATION)
+    bus: asyncio.PriorityQueue = hub.evbus.BUS
+    # This has to be the highest priority, so that it is processed in the last
+    bus.put_nowait((sys.maxsize, STOP_ITERATION))
 
 
 async def join(hub):
