@@ -4,12 +4,10 @@ import logging.handlers
 def wrapper(hub, **kwargs):
     class AsyncQueueWrapper:
         def __init__(self):
-            self.routing_key = kwargs.get("routing_key", "log")
             self.profile = kwargs.get("profile", "logger")
 
         def put_nowait(self, record: logging.LogRecord):
             hub.evbus.broker.put_nowait(
-                routing_key=self.routing_key,
                 profile=self.profile,
                 body=dict(
                     message=record.getMessage(),
